.. include:: ../warning.rst

Edition control
===============

This chapter covers the editing capabilities of |cubicweb|. It
explains html Form construction, the Edit Controller and their
interactions.


.. toctree::
   :maxdepth: 2

   form
   dissection
   editcontroller
   examples
